@@ -7,7 +7,7 @@ use Moo;
 use Math::Trig qw(:pi);
 use POSIX qw(ceil);
 
-our $VERSION = '0.0202';
+our $VERSION = '0.0203';
 
 use constant K => pi / 180;
 
@@ -150,9 +150,9 @@ sub forward {
     $self->x($x + $xo);
     $self->y($y + $yo);
 
-    return $self->pen_status == 1
-        ? ( ceil($xo), ceil($yo), ceil($self->x), ceil($self->y), $self->pen_color, $self->pen_size )
-        : undef;
+    return ceil($xo), ceil($yo),
+        ceil($self->x), ceil($self->y),
+        $self->pen_color, $self->pen_size;
 }
 
 
@@ -179,9 +179,9 @@ sub goto {
     $self->x($x);
     $self->y($y);
 
-    return $self->pen_status == 1
-        ? ( ceil($xo), ceil($yo), ceil($self->x), ceil($self->y), $self->pen_color, $self->pen_size )
-        : undef;
+    return ceil($xo), ceil($yo),
+        ceil($self->x), ceil($self->y),
+        $self->pen_color, $self->pen_size;
 }
 
 1;
@@ -198,12 +198,14 @@ Data::Turtle - Turtle Movement and State Operations
 
 =head1 VERSION
 
-version 0.0202
+version 0.0203
 
 =head1 SYNOPSIS
 
   use Data::Turtle;
+
   my $turtle = Data::Turtle->new;
+
   $turtle->pen_up;
   $turtle->right(45);
   $turtle->forward(10);
@@ -211,8 +213,10 @@ version 0.0202
   $turtle->mirror;
   $turtle->backward(10);
   $turtle->pen_down;
+
   my ($x, $y, $heading, $status, $color, $size) = $turtle->get_state;
   $turtle->set_state($x, $y, $heading, $status, $color, $size);
+
   for my $i (1 .. 4) {
       my @line = $turtle->forward(50);
       # if (@line) { ... # Draw it!
@@ -221,14 +225,14 @@ version 0.0202
 
 =head1 DESCRIPTION
 
-This module enables basic turtle movement and state operations without requiring
-any particular graphics package.
+This module enables basic turtle movement and state operations without
+requiring any particular graphics package.
 
-The methods don't draw anything.  They just set or output coordinates and
-values for drawing by your favorite graphics package.
+The methods don't draw anything.  They just set or output coordinates
+and values for drawing by your favorite graphics package.
 
-For examples with L<GD> and L<Imager>, please see the files in the F<eg/>
-distribution directory.
+For examples with L<GD> and L<Imager>, please see the files in the
+F<eg/> distribution directory.
 
 =head1 METHODS
 
@@ -337,7 +341,7 @@ Set the turtle state with the given parameters.
 
   @line = $turtle->forward($steps);
 
-Move forward the given number of steps.  If the pen is down, a list defining a
+Move forward the given number of steps, and return a list defining a
 line is returned with these values:
 
   x0, y0, x, y, pen_color, pen_size
@@ -346,7 +350,7 @@ line is returned with these values:
 
   @line = $turtle->backward($steps);
 
-Move backward the given number of steps.  If the pen is down, a list defining a
+Move backward the given number of steps, and return a list defining a
 line is returned with these values:
 
   x0, y0, x, y, pen_color, pen_size
@@ -361,7 +365,7 @@ Reflect the heading (by multiplying by -1).
 
   @line = $turtle->goto($x, $y);
 
-Move the pen to the given coordinate.  If the pen is down, a list defining a
+Move the pen to the given coordinate, and return a list defining a
 line is returned with these values:
 
   x0, y0, x, y, pen_color, pen_size
